@@ -184,7 +184,7 @@ bool ScriptMethods::scrInit(void)
 		
 		value = getContent(line->args[idx++]);
 		syms = getLocal();
-		sym = syms->find(++cp, strlen(value));
+		sym = syms->find(++cp, (unsigned short)strlen(value));
 		if(!sym)
 			continue;
 		if(sym->type != symINITIAL)
@@ -354,7 +354,7 @@ bool ScriptMethods::scrRemove(void)
 		if(!a->tail)
 			break;
 
-		len = strlen(opt);
+		len = (unsigned)strlen(opt);
 		while(idx < a->tail)
 		{
 			dp = sym->data + sizeof(Array) + idx * (a->rec + 1);
@@ -364,7 +364,7 @@ bool ScriptMethods::scrRemove(void)
 		}
 		if(a->head > idx)
 			--a->head;
-		while(idx < (a->tail - 1))
+		while(idx < (unsigned)(a->tail - 1))
 		{
 			strcpy(sym->data + sizeof(Array) + idx * (a->rec + 1),
 				sym->data + sizeof(Array) + (idx + 1) * (a->rec + 1));
@@ -385,7 +385,7 @@ bool ScriptMethods::scrRemove(void)
 			break;
 		}
 		cp = (char *)extract(sym);
-		len = strlen(buffer);
+		len = (unsigned int)strlen(buffer);
 		while(cp && *cp)
 		{
 			if(!strncmp(cp, opt, len))
@@ -1303,7 +1303,7 @@ bool ScriptMethods::scrIndex(void)
 		if(iNumber > 0)
 			--iNumber;
 
-		symindex(sym, iNumber);
+		symindex(sym, (short)iNumber);
 	}
 	skip();
 	return true;
@@ -1704,10 +1704,10 @@ bool ScriptMethods::scrOffset(void)
 		if((unsigned)(-offset) >= frame[stack].index)
 			frame[stack].index = 1;
 		else
-			frame[stack].index += offset;
+			frame[stack].index += (unsigned short)offset;
 	}
 	else
-		frame[stack].index += offset;
+		frame[stack].index += (unsigned short)offset;
 	updated = false;
 	return execute(frame[stack].line->method);
 }
