@@ -107,9 +107,15 @@ ScriptRegistry::ScriptRegistry()
         Script::plugins = 
 		"C:/Program Files/Common Files/CAPE Framework/Script Plugins";
 
+#ifdef	DEBUG
+#define	PLUGINS "Debug"
+#else
+#define	PLUGINS "Plugins"
+#endif
+
         if(RegOpenKey(HKEY_LOCAL_MACHINE, REGISTRY_SCRIPT_SETTINGS, &key) == ERROR_SUCCESS)
         {
-			if(RegQueryValue(key, "Plugins", regpath, &value) == ERROR_SUCCESS)
+			if(RegQueryValue(key, PLUGINS, regpath, &value) == ERROR_SUCCESS)
 			{
                         Script::plugins = regpath;
                         env = regpath;
